// java wrapper for vtkAreaContourSpectrumFilter object
//

package vtk;
import vtk.*;

public class vtkAreaContourSpectrumFilter extends vtkDataObjectAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetArcId_2(int id0);
  public void SetArcId(int id0)
    { SetArcId_2(id0); }

  private native int GetArcId_3();
  public int GetArcId()
    { return GetArcId_3(); }

  private native void SetNumberOfSamples_4(int id0);
  public void SetNumberOfSamples(int id0)
    { SetNumberOfSamples_4(id0); }

  private native int GetNumberOfSamples_5();
  public int GetNumberOfSamples()
    { return GetNumberOfSamples_5(); }

  private native void SetFieldId_6(int id0);
  public void SetFieldId(int id0)
    { SetFieldId_6(id0); }

  private native int GetFieldId_7();
  public int GetFieldId()
    { return GetFieldId_7(); }

  private native long GetOutput_8();
  public vtkTable GetOutput() {
    long temp = GetOutput_8();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkAreaContourSpectrumFilter() { super(); }

  public vtkAreaContourSpectrumFilter(long id) { super(id); }
  public native long   VTKInit();

}
